@@ -4,8 +4,15 @@
 (* Copyright (C) --- OCamlPro --- See README.md for information and licensing *)
 (******************************************************************************)
 
+open ExtSigs
+
+val src : Logs.src
+
 module Make
-  (Var : ExtSigs.VAR_SIG)
-  (R   : ExtSigs.R_SIG)
-  (Ex  : ExtSigs.EX_SIG)
-  : CoreSig.SIG with module Var = Var and module R = R and module Ex = Ex
+  (Var : Variables)
+  (R   : Rationals)
+  (Ex  : Explanations)
+  : CoreSig.S
+    with module Var = Var
+     and module R = R
+     and module Ex = Ex
