@@ -4,9 +4,9 @@
 (* Copyright (C) --- OCamlPro --- See README.md for information and licensing *)
 (******************************************************************************)
 
-module type SIG = sig
-  module Core : CoreSig.SIG
+module type S = sig
+  module Core : CoreSig.S
   val get : (Core.P.t * bool) option -> Core.t -> Core.result
 end
 
-module Make(Core : CoreSig.SIG) : SIG with module Core = Core
+module Make(Core : CoreSig.S) : S with module Core = Core
